![Honeybee](http://www.ladybug.tools/assets/img/honeybee.png)

# honeybee-core

Honeybee core library.

# NOTE

This repository will be renamed to `honeybee` once the current `honeybee` repository is
renamed to `honeybee-radiance`.

## What is this repository?

Honeybee is a collection of Python library to create, run and visualize the results of
daylight ([RADIANCE](https://radiance-online.org//)) and energy analysis
([EnergyPlus](https://energyplus.net/)/[OpenStudio](https://www.openstudio.net/)).

This repository is the main repository for Honeybee core libraries. To extend the
functionalities of this library you should install available Honeybee extensions or write
your own. See [here](https://github.com/ladybug-tools/honeybee-extension) to get started
with writing your first extension.

Here are a number of available extensions for Honeybee:

- [honeybee-energy](https://github.com/ladybug-tools/honeybee-energy): Adds Energy simulation to Honeybee.
